#
# spec file for package skiboot
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define build_firmware 0%{?is_opensuse} && !0%{?is_backports}

Name:           skiboot
Version:        6.5
Release:        lp151.5.3.1
Summary:        Tools for the OpenPower platform
License:        Apache-2.0
Group:          System/Management
Url:            https://github.com/open-power/skiboot
Source:         skiboot-%{version}.tar.gz
BuildRequires:  libopenssl-devel
BuildRequires:  linux-glibc-devel
BuildRequires:  systemd-rpm-macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}
ExclusiveArch:  ppc64 ppc64le

%description
OPAL firmware (OpenPower Abstraction Layer)

%package -n opal-prd
Summary:        OPAL Processor Recovery Diagnostics daemon
Group:          System/Management

%description -n opal-prd
This package provides a daemon to load and run the OpenPower firmware's
Processor Recovery Diagnostics binary. This is responsible for run time
maintenance of OpenPower Systems hardware.

%package -n opal-utils
Summary:        OPAL firmware utilities
Group:          System/Management

%description -n opal-utils
This package contains utility programs.

The 'gard' utility can read, parse and clear hardware gard partitions
on OpenPower platforms. The 'getscom' and 'putscom' utilities provide
an interface to query or modify the registers of the different chipsets
of an OpenPower system. 'pflash' is a tool to access the flash modules
on such systems and update the OpenPower firmware.

%package -n     opal-firmware
Summary:        OPAL firmware
Group:          System/Management
BuildArch:      noarch

%description -n opal-firmware
OPAL firmware, aka skiboot, loads the bootloader and provides runtime
services to the OS (Linux) on IBM Power and OpenPower systems.

%prep
%setup -q

%build
%if %build_firmware
SKIBOOT_VERSION=%version CROSS= make V=1 %{?_smp_mflags}
%endif
OPAL_PRD_VERSION=%version make V=1 %{?_smp_mflags} -C external/opal-prd
GARD_VERSION=%version make V=1 %{?_smp_mflags} -C external/gard
PFLASH_VERSION=%version make V=1 %{?_smp_mflags} -C external/pflash
XSCOM_VERSION=%version make V=1 -C external/xscom-utils

%install
%make_install -C external/opal-prd/ prefix=%{_prefix}
%make_install -C external/gard/ prefix=%{_prefix}
%make_install -C external/xscom-utils/ prefix=%{_prefix}
%make_install -C external/pflash/ prefix=%{_prefix}

mkdir -p %{buildroot}/%{_unitdir}
install -D -m 444 -p external/opal-prd/opal-prd.service %{buildroot}%{_unitdir}/opal-prd.service

%if %build_firmware
mkdir -p %{buildroot}%{_datadir}/qemu
install -m 644 -p skiboot.lid %{buildroot}%{_datadir}/qemu/skiboot.lid
%endif

%pre -n opal-prd
%service_add_pre opal-prd.service

%post -n opal-prd
%service_add_post opal-prd.service

%preun -n opal-prd
%service_del_preun opal-prd.service

%postun -n opal-prd
%service_del_postun opal-prd.service

%files -n opal-prd
%defattr(-,root,root)
%doc README.md LICENCE
%{_sbindir}/opal-prd
%{_mandir}/man8/opal-prd.8.gz
%{_unitdir}/opal-prd.service

%files -n opal-utils
%defattr(-,root,root)
%doc README.md LICENCE
%{_sbindir}/opal-gard
%{_sbindir}/getscom
%{_sbindir}/putscom
%{_sbindir}/getsram
%{_sbindir}/pflash
%{_mandir}/man1/opal-gard.1.gz
%{_mandir}/man1/getscom.1.gz
%{_mandir}/man1/getsram.1.gz
%{_mandir}/man1/putscom.1.gz
%{_mandir}/man1/pflash.1.gz

%if %build_firmware
%files -n opal-firmware
%doc README.md LICENCE
%{_datadir}/qemu/
%endif

%changelog
* Tue Aug 20 2019 Michel Normand <normand@linux.vnet.ibm.com>
- version update from 6.2.2 to 6.5
  - Support for Memory-preserving IPL (MPIPL)
  - Support for the Swift platform and NPU3 hardware.
  - Support for the Mihawk platform
  - npu2-opencapi: Add opencapi support on ZZ
  - platforms/nicole: Add new platform
  - platform/zz: Add new platform type
  - nvram: Flag dangerous NVRAM options
  - hw/phb3: Add verbose EEH output
  - Experimental support for building without FSP code
  - doc: travis-ci deploy docs!
  - Big OPAL API Documentation improvement
  - opal/hmi: Report NPU2 checkstop reason
  - opal-msg: Enhance opal-get-msg API
  - core/opal: Increase opal-msg-size size
  - hw/npu2-opencapi: Add initial support for allocating OpenCAPI LPC memory
  - core/fast-reboot: Add im-feeling-lucky option
  - platforms/astbmc: Check for SBE validation step
  - Add P9 DIO interrupt support
  - hw/imc: Enable opal calls to init/start/stop IMC Trace mode
  - xive: Add calls to save/restore the queues and VPs HW state
  - witherspoon: Add nvlink2 interconnect information
  - platforms/romulus: Also support talos
  - OpenCAPI support!
  - opal/hmi: set a flag to inform OS that TOD/TB has failed.
  - astbmc: Enable IPMI HIOMAP for AMI platforms
  - power-mgmt : occ : Add 'freq-domain-mask' DT property
  - powercap: occ: Fix the powercapping range allowed for user
  - Add NVDIMM support
  - core/exceptions: implement support for MCE interrupts in powersave
  - core/exceptions: implement an exception handler for non-powersave sresets
  - Add PVR_TYPE_P9P
  - Expose PNOR Flash partitions to host MTD driver via devicetree
  - Write boot progress to LPC port 80h
  - Write boot progress to LPC ports 81 and 82
  - Add Talos II platform
  - cpufeatures: Add tm-suspend-hypervisor-assist and tm-suspend-xer-so-bug node
- details release notes since previous v6.2.2:
  https://github.com/open-power/skiboot/tree/master/doc/release-notes
- remove patches embeded in new version
  libffs-fix-string-truncation.patch
  struct-p9_sbe_msg-doesn-t-need-to-be-packed.patch
  hdata-vpd-fix-printing-char-0x00.patch
  errorlog-Prevent-alignment-error-buiding-with-gcc9.patch
* Tue Jul 23 2019 Michal Suchanek <msuchanek@suse.de>
- Fix aligment error with gcc9.
  - add errorlog-Prevent-alignment-error-buiding-with-gcc9.patch
  - add hdata-vpd-fix-printing-char-0x00.patch
  - add struct-p9_sbe_msg-doesn-t-need-to-be-packed.patch
  - refresh libffs-fix-string-truncation.patch
* Wed Mar 13 2019 michel normand <normand@linux.vnet.ibm.com>
- version update to 6.2.2
  - powercap: occ: Fix the powercapping range allowed for user
  - astbmc: Enable IPMI HIOMAP for AMI platforms
  - astbmc: Try IPMI HIOMAP for P8 (again)
  - p8dtu: Enable HIOMAP support
  - p8dtu: Configure BMC graphics
  - ipmi-hiomap test case enhancements/fixes.
  - libflash/ipmi-hiomap: Enforce message size for empty response
  - libflash/ipmi-hiomap: Remove unused close handling
  - libflash/ipmi-hiomap: Overhaul event handling
  - libflash/ipmi-hiomap: Overhaul error handling
  - libflash/ipmi-hiomap: Fix leak of msg in callback
  - core/ipmi: Add ipmi sync messages to top of the list
  - hw/bt: Introduce separate list for synchronous messages
  - hw/bt: Fix message retry handler
  - ipmi/power: Fix system reboot issue
  - hw/bt: Add backend interface to disable ipmi message retry option
  - qemu: bt device isn't always hanging off /
  - hw/phb3/naples: Disable D-states
* Wed Feb 20 2019 Michel Normand <normand@linux.vnet.ibm.com>
- version update to 6.2.1
  - skiboot 6.2.1 was released on Wednesday February 20th, 2019.
    replaces skiboot-6.2 as current stable release in 6.2.x series.
  - core/cpu: HID update race
  - core/ipmi: Improve error message
  - core/lock: Stop drop_my_locks() from always causing abort
  - core/opal: Print PIR value in exit path, useful for debugging
  - cpufeatures: Always advertise POWER8NVL as DD2
  - firmware-versions: Add test case for parsing VERSION
  - libflash/ecc: Fix compilation warning with gcc9
    Fixes: https://github.com/open-power/skiboot/issues/218
  - p9dsu: Fix p9dsu default variant
  - p9dsu: Fix p9dsu slot tables
  - for details refer to:
    https://github.com/open-power/skiboot/commit/0647f2a
* Wed Feb 13 2019 Jan Engelhardt <jengelh@inai.de>
- Trim those %%if..%%endif guards that do not affect the build
  result.
- Use %%make_install.
* Wed Feb 13 2019 normand@linux.vnet.ibm.com
- version update to 6.2
  - skiboot v6.2 was released on Friday December 14th 2018.
    It is the first release of skiboot 6.2,
    which becomes the new stable release of skiboot.
  - for details refer to:
    https://github.com/open-power/skiboot/releases/tag/v6.2
- remove hdata-i2c.c-fix-building-with-gcc8.patch now in 6.2
- remove opal-prd-Fix-opal-prd-crash.patch now in 6.2
* Mon Feb 11 2019 Michal Suchanek <msuchanek@suse.de>
- Fix opal-prd crash when building with -pie (bsc#1124931).
  - add opal-prd-Fix-opal-prd-crash.patch
* Wed Jan 30 2019 Michal Suchanek <msuchanek@suse.com>
- skiboot.lid conflicts with qemu which is not allowed in backports so build
  opal-firmware on OpenSUSE only (bsc#1123072).
* Thu Jan 24 2019 Michal Suchanek <msuchanek@suse.com>
- Fix build on Tumbleweed.
  - add hdata-i2c.c-fix-building-with-gcc8.patch
  - add libffs-fix-string-truncation.patch
* Mon Apr 23 2018 normand@linux.vnet.ibm.com
- Add few lines below about changes version 5.10
* Wed Apr 18 2018 normand@linux.vnet.ibm.com
- version update to 5.10
  - skiboot v5.10 contains all bug fixes as of skiboot-5.9.8 and
    skiboot-5.4.9. We do not forsee any further 5.9.x releases.
  - Power9 support
    Power saving -Secure and Trusted Boot
    XIVE -PCI -PHB4 -CAPI -NVLINK2
  - for details refer to:
    https://github.com/open-power/skiboot/blob/master/doc/release-notes/skiboot-5.10.rst
- remove increase_dpath_string.patch
* Sun Dec 17 2017 normand@linux.vnet.ibm.com
- version update to 5.9.6
  - see https://github.com/open-power/skiboot/blob/master/doc/release-notes/skiboot-5.9.6.rst
- add increase_dpath_string.patch
* Wed Apr 12 2017 normand@linux.vnet.ibm.com
- version update to 5.5.0
  - see https://github.com/open-power/skiboot/blob/master/doc/release-notes/skiboot-5.5.0.rst
- remove two patches now upstream:
  0001-Make-links-target-reusable.patch
  skiboot_gcc6_backtrace.patch
* Fri Jun 17 2016 normand@linux.vnet.ibm.com
- new skiboot_gcc6_backtrace.patch
* Tue Mar 29 2016 dvaleev@suse.com
- Reenable parallel build
  0001-Make-links-target-reusable.patch (bsc#987201).
* Thu Mar 24 2016 dvaleev@suse.com
- Drop opal-prd.{service,socket}, use upstream one
- Disable parallel builds
  (see https://github.com/open-power/skiboot/issues/27, bsc#987201)
* Tue Mar 22 2016 jloeser@suse.com
- version update to 5.2.0 (FATE#320438)
  - see https://github.com/open-power/skiboot/blob/master/doc/release-notes/skiboot-5.2.0.txt
* Sat Jan 30 2016 mpluskal@suse.com
- Update to 5.1.13
  * See https://github.com/open-power/skiboot/blob/master/doc/release-notes/skiboot-5.1.13.txt
* Sat Jan  2 2016 mpluskal@suse.com
- Update to 5.1.12
  * opal-prd:
    + Display an explict and obvious message if running on a
    system that does not support opal-prd, such as an IBM FSP
    based POWER system, where the FSP takes on the role of
    opal-prd.
  * pflash:
    + Fix a missing (C) header
    + cherry-picked from master.
  * General:
    + Don't link with libgcc
    + On some toolchains, we don't have libgcc available.
  * POWER8 PHB (PCIe) specific:
    + hw/phb3: Flush cache line after updating P/Q bits
    + When doing an MSI EOI, we update the P and Q bits in the
    IVE.
  * IBM FSP based machines:
    + FSP: Give up PSI link on shutdown This clears up some
    erroneous SRCs (error logs) in some situations.
    + Correctly report back Real Time Clock errors to host.
* Tue Oct 27 2015 dvaleev@suse.com
- Version update to 5.1.8
  skiboot-5.1.8 is the 9th stable release of 5.1, it follows skiboot-5.1.7
  (which was released October 13th, 2015).
  Skiboot 5.1.8 contains all fixes from skiboot-5.1.7 and is a minor bug
  fix release, with a single fix for recovery from a (rare) error.
  Over skiboot-5.1.7, we have the following change:
- opal/hmi: Fix a soft lockup issue on Hypervisor Maintenance Interrupt
  for certain timebase errors.
  We also introduce a timeout to handle the worst situation where all other
  threads are badly stuck without setting a cleanup done bit. Under such
  situation timeout will help to avoid soft lockups and report failure to
  kernel.
- Fix opal-prd.service file to include arguments
* Tue Oct 20 2015 dvaleev@suse.com
- Add ppc64 architecture, drop i2c-tools.
  i2c-dev.h is now shipped in linux-glibc-devel package
* Mon Oct 12 2015 dvaleev@suse.com
- Initial version 5.1.6
